"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = extractCode;

var _gfmCodeBlocks = _interopRequireDefault(require("gfm-code-blocks"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function isSupportedLang(block) {
  var lang = block.lang.split(" ")[0];
  return lang === "javascript" || lang === "js" || lang === "typescript" || lang === "ts";
}

function isTypescript(block) {
  var lang = block.lang.split(" ")[0];
  return lang === "typescript" || lang === "ts";
}

function isTest(block) {
  var tag = block.lang.split(" ")[1];
  return tag === "test" || tag === "should";
}

var arrowRegex = /\/(\/|\*)\s?(=>|→|throws)/;

function isAutomaticTest(block) {
  return block.code.match(arrowRegex);
}

function extractCode(markdown) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref$auto = _ref.auto,
      auto = _ref$auto === void 0 ? false : _ref$auto,
      _ref$all = _ref.all,
      all = _ref$all === void 0 ? false : _ref$all;

  var hasTypescript = false;
  var code = new Array(markdown.length).fill(" ");
  var newline = /\n/gm;
  var result;

  while (result = newline.exec(markdown)) {
    code[result.index] = "\n";
  }

  var blocks = (0, _gfmCodeBlocks["default"])(markdown).filter(all ? function () {
    return true;
  } : auto ? isAutomaticTest : isTest).filter(isSupportedLang);

  if (blocks.length === 0) {
    console.error("\nREADME has no test code blocks\n");
    process.exit(1);
  }

  blocks.forEach(function (block) {
    hasTypescript = hasTypescript || isTypescript(block);
    code.splice.apply(code, [block.start, block.end - block.start].concat(_toConsumableArray(block.code.padStart(block.end - block.start, " ").split(""))));
  });
  return {
    code: code.join(""),
    hasTypescript: hasTypescript
  };
}