"use strict";

var _assert = _interopRequireWildcard(require("assert"));

var _tapYaml = require("tap-yaml");

var _stackUtils = _interopRequireWildcard(require("stack-utils"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

console.log("TAP version 13");
var tests = 0;
var passes = 0;
var failures = 0;
var stackUtils = new _stackUtils["default"]({
  internals: [].concat(_toConsumableArray((0, _stackUtils.nodeInternals)()), [/\/readme-assert\/lib\//])
});

function printObject(obj) {
  console.log("  ---");
  console.log((0, _tapYaml.stringify)(obj, 4).replace(/^/gm, "  "));
  console.log("  ...");
}

function test(message, fn) {
  var _arguments = arguments;
  return function () {
    var args = Array.prototype.slice.call(_arguments);
    tests++;

    try {
      fn.apply(_assert["default"], [args]);
      console.log("ok ".concat(tests, " ").concat(message || ""));
      passes++;
    } catch (err) {
      console.log("not ok ".concat(tests, " ").concat(message || ""));
      failures++;

      if ("actual" in err && "expected" in err && "operator" in err) {
        printObject({
          operator: err.operator,
          actual: err.actual,
          expected: err.expected,
          stack: stackUtils.clean(err.stack).split("\n").slice(1).join("\n")
        });
      } else {
        printObject(err);
      }
    }
  }();
}

var assert = function assert(value, message) {
  return test(message, function () {
    return (0, _assert["default"])(value, message);
  });
};

assert.deepEqual = function (actual, expected, message) {
  test(message, function () {
    return (0, _assert.deepEqual)(actual, expected, message);
  });
};

assert.deepStrictEqual = function (actual, expected, message) {
  test(message, function () {
    return (0, _assert.deepStrictEqual)(actual, expected, message);
  });
};

assert.doesNotThrow = function (block, error, message) {
  test(message, function () {
    return (0, _assert.doesNotThrow)(block, error, message);
  });
};

assert.equal = function (actual, expected, message) {
  test(message, function () {
    return (0, _assert.equal)(actual, expected, message);
  });
};

assert.fail = function (actual, expected, message, operator) {
  test(message, function () {
    return (0, _assert.fail)(actual, expected, message, operator);
  });
};

assert.ifError = function (value) {
  test("", function () {
    return (0, _assert.ifError)(value);
  });
};

assert.notDeepEqual = function (actual, expected, message) {
  test(message, function () {
    return (0, _assert.notDeepEqual)(actual, expected, message);
  });
};

assert.notDeepStrictEqual = function (actual, expected, message) {
  test(message, function () {
    return (0, _assert.notDeepStrictEqual)(actual, expected, message);
  });
};

assert.ok = function (value, message) {
  test(message, function () {
    return (0, _assert.ok)(value, message);
  });
};

assert["throws"] = function (block, error, message) {
  test(message, function () {
    return (0, _assert["throws"])(block, error, message);
  });
};

process.on("uncaughtException", function (err) {
  console.log("Bail out! Uncaught exception ".concat(err.name));
  printObject(err);
  process.exit(1);
});
process.on("exit", function (code) {
  if (code === 0) {
    console.log("1..".concat(tests));
    console.log("# tests ".concat(tests));
    console.log("# pass ".concat(passes));
    console.log("# fail ".concat(failures));

    if (failures > 0) {
      process.reallyExit(1);
    }
  }
});
global.assert = assert;