"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = run;

var babel = _interopRequireWildcard(require("@babel/core"));

var _pluginTransformTypescript = _interopRequireDefault(require("@babel/plugin-transform-typescript"));

var _presetEnv = _interopRequireDefault(require("@babel/preset-env"));

var _babelPluginTransformCommentToAssert = _interopRequireDefault(require("babel-plugin-transform-comment-to-assert"));

var _babelPluginTransformRenameImport = _interopRequireDefault(require("babel-plugin-transform-rename-import"));

var _sourceMapSupport = _interopRequireDefault(require("source-map-support"));

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _pkgUp = _interopRequireDefault(require("pkg-up"));

var _extract2 = _interopRequireDefault(require("./extract"));

var _runInThisContext = require("./runInThisContext");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function run(main, req, shouldPrintCode, babelrc, filePath, auto, all) {
  var sourceMaps = !shouldPrintCode;
  var sourceMapsFile = shouldPrintCode ? _path["default"].join(_path["default"].dirname(filePath), "readme.md.js") : filePath;
  req.forEach(function (f) {
    require(require.resolve(f, {
      paths: [process.cwd()]
    }));
  });

  var mdDirname = _path["default"].dirname(filePath);

  process.chdir(mdDirname);
  var mdText = read(filePath);

  var rootPkg = _pkgUp["default"].sync();

  var pkg = JSON.parse(read(rootPkg));

  var _extract = (0, _extract2["default"])(mdText, {
    auto: auto,
    all: all
  }),
      code = _extract.code,
      hasTypescript = _extract.hasTypescript;

  var transformed = babel.transform(code, {
    babelrc: babelrc,
    sourceMaps: sourceMaps,
    plugins: [].concat(_toConsumableArray(hasTypescript ? [_pluginTransformTypescript["default"]] : []), [_babelPluginTransformCommentToAssert["default"], rootPkg ? [_babelPluginTransformRenameImport["default"], {
      replacement: main || process.cwd(),
      original: pkg.name
    }] : undefined]),
    presets: [_presetEnv["default"]],
    filename: sourceMapsFile
  });

  if (sourceMaps) {
    _sourceMapSupport["default"].install({
      retrieveSourceMap: function retrieveSourceMap(request) {
        if (request === filePath) {
          return {
            url: sourceMapsFile,
            map: transformed.map
          };
        }

        return null;
      }
    });
  }

  if (shouldPrintCode) {
    printCode(transformed.code, sourceMapsFile);
  }

  require("./global-assert");

  (0, _runInThisContext.runInThisContext)(transformed.code, sourceMapsFile);
}

function read(file) {
  return _fs["default"].readFileSync(_path["default"].join(file), "utf-8");
}

function printCode(code, sourceMapsFile) {
  console.log("\n# ", sourceMapsFile);
  code.split("\n").forEach(function (l, i) {
    return console.log("# ".concat(String(i + 1).padEnd(3, " "), " ").concat(l));
  });
}